@@ -259,7 +259,8 @@ async def main() -> None:
                                        f"Manufacturer: {_node.manufacturer}\n"\
                                        f"Model: {_node.model}\n"\
                                        f"Serial #: {_node.serial}\n"\
-                                       f"Firmware: {_node.firmware.get('version')}"
+                                       f"Firmware: {_node.firmware.get('version')}\n"\
+                                       f"Latest Firmware: {_node.firmware.get('latest_version')}"
                             sections.append(section)
                         # endregion
 
@@ -267,10 +268,10 @@ async def main() -> None:
                         if args.get_network or all_args:
                             _LOGGER.debug("Preparing node network details")
                             section = "Network Details"
-                            section += f"\n{'-' * len(section)}\n"
+                            section += f"\n{'-' * len(section)}"
                             for adapter in _node.network:
-                                section += f"{adapter.get('type')} "\
-                                           f"(IP: {adapter.get('ip')}, MAC: {adapter.get('mac')})\n"
+                                section += f"\n{adapter.get('type')} "\
+                                           f"(IP: {adapter.get('ip')}, MAC: {adapter.get('mac')})"
                             sections.append(section)
                         # endregion
 
@@ -283,14 +284,14 @@ async def main() -> None:
                             sections.append(section)
                         # endregion
 
-                        # region #-- get the connected devices: format = name (IP) --#
+                        # region #-- get the connected devices: format = name (IP) (Type) --#
                         if args.get_connected_devices or all_args:
                             _LOGGER.debug("Preparing node connected devices")
                             section = "Connected Devices"
                             section += f"\n{'-' * len(section)}\n"
                             device: dict
                             for device in _node.connected_devices:
-                                section += f"{device.get('name')} ({device.get('ip')})\n"
+                                section += f"{device.get('name')} ({device.get('ip')}) ({device.get('type')})\n"
                             sections.append(section.rstrip("\n"))
                         # endregion
                 elif args.target == 'device':
@@ -298,19 +299,33 @@ async def main() -> None:
                     if not _device:
                         args_parser.error(f"Invalid device name ({args.name}).")
                     else:
-                        _device: Device = _device[0]
-                        # region #-- get the overview details --#
-                        if all_args:
-                            _LOGGER.debug("Preparing device overview")
-                            connected_adapters: List = [adapter.get('ip') for adapter in _device.connected_adapters]
-                            section = "Overview"
-                            section += f"\n{'-' * len(section)}\n"
-                            section += f"Name: {_device.name}\n"\
-                                       f"Online: {_device.status}\n"\
-                                       f"IP: {','.join(connected_adapters)}\n"\
-                                       f"Parent: {_device.parent_name}"
-                            sections.append(section)
-                        # endregion
+                        for _d in _device:
+                            # region #-- get the overview details --#
+                            if all_args:
+                                _LOGGER.debug("Preparing device overview")
+                                connected_adapters: List = [adapter.get('ip') for adapter in _d.connected_adapters]
+                                section = "Overview"
+                                section += f"\n{'-' * len(section)}\n"
+                                section += f"Name: {_d.name}\n"\
+                                           f"Online: {_d.status}\n"\
+                                           f"IP: {','.join(connected_adapters)}\n"\
+                                           f"Parent: {_d.parent_name}\n"\
+                                           f"Parental Control:\n"\
+                                           f"  Blocked Times:"
+                                for day, rule in _d.parental_control_schedule.get(
+                                        'blocked_internet_access',
+                                        {}
+                                ).items():
+                                    section += f"\n    {day.title()}: {', '.join(rule)}"
+                                else:
+                                    if not _d.parental_control_schedule.get('blocked_internet_access', {}):
+                                        section += " N/A"
+                                blocked_sites_text = ", ".join(_d.parental_control_schedule.get('blocked_sites', []))\
+                                                     if _d.parental_control_schedule.get('blocked_sites', [])\
+                                                     else "N/A"
+                                section += f"\n  Blocked Sites: {blocked_sites_text}"
+                                sections.append(section)
+                            # endregion
         if sections:
             print("\n\n".join(sections))
 
