@@ -203,7 +203,7 @@ class Mesh:
 
         return self
 
-    async def __aexit__(self, exc_type, exc, traceback):
+    async def __aexit__(self, exc_type, exc, traceback) -> None:
         """Asynchronous exit magic method"""
         await self.close()
 
@@ -299,6 +299,7 @@ class Mesh:
         :param include_guest_wifi: True to include details about the guest Wi-Fi
         :param include_parental_control: True to include details about Parental Control
         :param include_speedtest_results: True to include the latest completed Speedtest result
+        :param include_firmware_update: True to include the current firmware update details (does not issue a check)
         :param include_wan: True to include WAN details
         :return: A dictionary containing the relevant details.  Keys used will match those of the instance variable.
         """
@@ -367,6 +368,17 @@ class Mesh:
         resp = await self.__async_make_request(action=const.ACTION_JNAP_TRANSACTION, payload=payload)
         responses = resp.get("responses", [])
         if responses:
+            # region #-- populate the update check details --#
+            # this needs to happen early because we'll use the results when populating the node details
+            idx = _get_action_index(
+                action=const.ACTION_JNAP_GET_UPDATE_FIRMWARE_STATE,
+                payload=payload
+            )
+            if idx is not None:
+                ret[const.ATTR_MESH_UPDATE_FIRMWARE_STATE] = responses[idx] \
+                    .get(const.KEY_ACTION_JNAP_RESPONSE_RESULTS, {})
+            # endregion
+
             # region #-- populate device and node details --#
             idx = _get_action_index(
                 action=const.ACTION_JNAP_GET_DEVICES,
@@ -393,33 +405,54 @@ class Mesh:
             devices = []
             for device in device_info:
                 if "nodeType" in device:
+                    # region #-- determine the backhaul information --#
                     device_backhaul = [bi for bi in backhaul_info if bi.get("deviceUUID") == device.get("deviceID")]
                     if device_backhaul:
                         device_backhaul = device_backhaul[0]
                     else:
                         device_backhaul = {}
-                    n = Node(**device, **{"backhaul": device_backhaul})
+                    # endregion
+                    # region #-- calculate if there is a firmware update available --#
+                    node_firmware: Union[List, dict] = {}
+                    if const.ATTR_MESH_UPDATE_FIRMWARE_STATE in ret:
+                        firmware_status = ret[const.ATTR_MESH_UPDATE_FIRMWARE_STATE].get("firmwareUpdateStatus", [])
+                        node_firmware = [
+                            firmware_details
+                            for firmware_details in firmware_status
+                            if firmware_details.get("deviceUUID") == device.get("deviceID")
+                        ]
+                        if node_firmware:
+                            node_firmware = node_firmware[0]
+                    # endregion
+                    n = Node(**device, **{"backhaul": device_backhaul, "updates": node_firmware})
                     devices.append(n)
                 else:
                     d = Device(**device)
                     devices.append(d)
             # endregion
 
-            # region #-- calculate the connected devices for nodes and parent name for devices --#
+            # region #-- post processing devices and nodes --#
             for node in devices:
                 if node.__class__.__name__.lower() == "node":
+                    # region #-- calculate the connected devices for nodes --#
                     connected_devices: List = []
+                    parent_name: Union[str, None] = None
                     for device in devices:
                         for adapter in device.network:
                             if adapter.get("parent_id") == node.unique_id:
-                                connected_devices.append({"name": device.name, "ip": adapter.get("ip")})
-                            if node.parent_ip:
+                                connected_devices.append({
+                                    "name": device.name,
+                                    "ip": adapter.get("ip"),
+                                    "type": adapter.get("type"),
+                                })
+                            if node.parent_ip and not parent_name:
                                 if node.parent_ip == adapter.get("ip"):
-                                    setattr(node, "parent_name", device.name)
-                            else:
-                                setattr(node, "parent_name", None)
+                                    parent_name = device.name
+                    setattr(node, "parent_name", parent_name)
                     setattr(node, "_Node__connected_devices", connected_devices)
+                    # endregion
                 elif node.__class__.__name__.lower() == "device":
+                    # region #-- calculate parent name for devices --#
                     attrib_connections = getattr(node, "_Device__attributes", {}).get("connections", [])
                     parent: Union[str, None] = None
                     for conn in attrib_connections:
@@ -433,6 +466,25 @@ class Mesh:
                             except IndexError:
                                 pass
                     setattr(node, "parent_name", parent)
+                    # endregion
+                    # region #-- get the parental control details --#
+                    pc_schedule: List = []
+                    if kwargs.get("include_parental_control"):
+                        idx = _get_action_index(
+                            action=const.ACTION_JNAP_GET_PARENTAL_CONTROL_INFO,
+                            payload=payload
+                        )
+                        if idx is not None:
+                            pc_details = responses[idx] \
+                                .get(const.KEY_ACTION_JNAP_RESPONSE_RESULTS, {})
+                            network_adapater_macs = [adapter.get("mac") for adapter in node.network]
+                            for mac in network_adapater_macs:
+                                for rule in pc_details.get("rules", []):
+                                    if mac in rule.get("macAddresses", []):
+                                        pc_schedule.append(rule)
+                                        break
+                    getattr(node, "_Device__attributes", {})["parental_controls"] = pc_schedule
+                    # endregion
             # endregion
 
             if devices:
@@ -499,16 +551,6 @@ class Mesh:
                 )
             # endregion
 
-            # region #-- populate the update check details --#
-            idx = _get_action_index(
-                action=const.ACTION_JNAP_GET_UPDATE_FIRMWARE_STATE,
-                payload=payload
-            )
-            if idx is not None:
-                ret[const.ATTR_MESH_UPDATE_FIRMWARE_STATE] = responses[idx] \
-                    .get(const.KEY_ACTION_JNAP_RESPONSE_RESULTS, {})
-            # endregion
-
         return ret
 
     async def __async_set_guest_wifi_state(self, state: bool, radios: Union[List, None] = None) -> None:
